==> dart_chainsql_api-1.0.5.tar.gz: lib/src/chainsql_api.dart <==
import 'dart:typed_data';
//import 'dart:convert' as convert;

import 'package:encrypt/encrypt.dart';

import 'package:dart_chainsql_api/src/core/serialized/enums/TransactionType.dart';
import 'package:dart_chainsql_api/src/utils/Util.dart';

import 'package:pointycastle/digests/sha256.dart';
import 'package:pointycastle/digests/ripemd160.dart';

import 'ecdsa/IkeyPair.dart';
import 'ecdsa/Seed.dart';
import 'ecdsa/Ecies.dart';

import 'package:dart_chainsql_api/src/utils/B58IdentiferCodecs.dart';

import 'package:dart_chainsql_api/src/core/types/tx/Transaction.dart';
import 'package:dart_chainsql_api/src/core/types/signed/SignedTransaction.dart';

import 'package:dart_chainsql_api/src/model/wallet.dart';
import 'package:dart_chainsql_api/src/model/sign_tx.dart';
import 'package:dart_chainsql_api/src/ecdsa/K256KeyPair.dart';


class Chainsql {

  ///
  /// Generate a new account.
  ///
  /// @return Contains folling fields:
  /// secret:Account secret.
  /// address:Account address.
  /// publicKey:Account publickey.
  ////
  static Wallet generateAddress() {
    // Security.addProvider(new BouncyCastleProvider());
    Seed seed = Seed.randomSeed();
    return generateAddressFromSeed(seed);
  }

  static Wallet generateAddressFromStr(String secret) {
    Seed seed = Seed.fromBase58(secret);
    return generateAddressFromSeed(seed);
  }

  static Wallet generateAddressFromSeed(Seed seed) {
    IKeyPair keyPair = seed.keyPair();
    Uint8List pubBytes = keyPair.canonicalPubBytes();

    //keyPair.getPriv();

    print(keyPair.getPriv().toRadixString(16));
    print(keyPair.getPub().toRadixString(16));

    SHA256Digest sha = new SHA256Digest();
    sha.update(pubBytes, 0, pubBytes.length);

    var result = new Uint8List(sha.digestSize);
    sha.doFinal(result, 0);

    RIPEMD160Digest d = new RIPEMD160Digest();
    d.update(result, 0, result.length);
    var o = new Uint8List(d.digestSize);
    d.doFinal(o, 0);

    String publicKey = B58IdentiferCodecs.encode(
        pubBytes, B58IdentiferCodecs.VER_ACCOUNT_PUBLIC);
    String secretKey = B58IdentiferCodecs.encodeFamilySeed(seed.bytes());
    String address = B58IdentiferCodecs.encodeAddress(o);

    return new Wallet(secretKey, address, publicKey);
  }

  /// Return the signed Hex String
  static String signFromString(String data, String secret) {

      Seed seed = Seed.fromBase58(secret);
      IKeyPair keyPair = seed.keyPair();
      var signedData = keyPair.signMessage(Util.createUint8ListFromString(data));
      return Util.formatBytesAsHexString(signedData);
  }

  static Uint8List sign(Uint8List data, String secret) {
    Seed seed = Seed.fromBase58(secret);
    IKeyPair keyPair = seed.keyPair();
    return keyPair.signMessage(data);
  }


  static bool verify(Uint8List data,Uint8List sig,String publicKey){
    Uint8List pubBytes = Util.getPubBytesFromString(publicKey);

    K256KeyPair keyPair = new K256KeyPair(null,Util.createBigIntFromUint8List(pubBytes));
    return keyPair.verifySignature(data, sig);
  }


  static SignTx signTxFromJson(Map txJson){

    if (txJson == null || !txJson.containsKey('secret')) {
      throw Exception("missing key 'secret'");
    }

    return signTx(txJson, txJson['secret']);
  }

  static SignTx signTx(Map txMap, String secret) {
    if (txMap == null || !txMap.containsKey('tx_json')) {
      throw Exception("missing key 'tx_json'");
    }

    Map tx = txMap['tx_json'];
    if (!tx.containsKey('TransactionType')) {
      throw Exception("missing key 'TransactionType'");
    }

    TransactionType type = TransactionType.valueOf(tx['TransactionType']);
    Transaction transaction = new Transaction(type);

    transaction.parseFromJson(tx);

    SignedTransaction signed = transaction.sign(secret);
    return new SignTx(signed.tx_blob, signed.hash.toString());
  }

  static Uint8List aes256Encrypt(Uint8List plainBytes, Uint8List symKey) {
    final key = new Key(Util.paddingPass(symKey, 32));
    final iv = new IV(key.bytes.sublist(0, 16));

    final encrypter = Encrypter(AES(key, mode: AESMode.cbc));
    final encrypted = encrypter.encryptBytes(plainBytes, iv: iv);
    return encrypted.bytes;
  }

  static Uint8List aes256Descrypt(Uint8List cipherBytes, Uint8List symKey) {
    final key = new Key(Util.paddingPass(symKey, 32));
    final iv = new IV(key.bytes.sublist(0, 16));
    final encrypter = Encrypter(AES(key, mode: AESMode.cbc));
    Encrypted encrypted = new Encrypted(cipherBytes);
    final decrypted = encrypter.decryptBytes(encrypted, iv: iv);
    return Uint8List.fromList(decrypted);
  }

  static Uint8List eciesEncrypt(Uint8List plainBytes,String publicKey){
    Uint8List pubBytes = Util.getPubBytesFromString(publicKey);
    return Ecies.eciesEncrypt(plainBytes, pubBytes);
  }

  static Uint8List eciesDecrypt(Uint8List cipher,String secret){
    return Ecies.eciesDecrypt(cipher, Seed.fromBase58(secret));
  }

}

==> dart_chainsql_api-1.0.6.tar.gz: lib/src/chainsql_api.dart <==
import 'dart:typed_data';
//import 'dart:convert' as convert;

import 'package:encrypt/encrypt.dart';

import 'package:dart_chainsql_api/src/core/serialized/enums/TransactionType.dart';
import 'package:dart_chainsql_api/src/utils/Util.dart';

import 'package:pointycastle/digests/sha256.dart';
import 'package:pointycastle/digests/ripemd160.dart';

import 'ecdsa/IkeyPair.dart';
import 'ecdsa/Seed.dart';
import 'ecdsa/Ecies.dart';

import 'package:dart_chainsql_api/src/utils/B58IdentiferCodecs.dart';

import 'package:dart_chainsql_api/src/core/types/tx/Transaction.dart';
import 'package:dart_chainsql_api/src/core/types/signed/SignedTransaction.dart';

import 'package:dart_chainsql_api/src/model/wallet.dart';
import 'package:dart_chainsql_api/src/model/sign_tx.dart';
import 'package:dart_chainsql_api/src/ecdsa/K256KeyPair.dart';


class Chainsql {

  ///
  /// Generate a new account.
  ///
  /// @return Contains folling fields:
  /// secret:Account secret.
  /// address:Account address.
  /// publicKey:Account publickey.
  ////
  static Wallet generateAddress() {
    // Security.addProvider(new BouncyCastleProvider());
    Seed seed = Seed.randomSeed();
    return generateAddressFromSeed(seed);
  }

  static Wallet generateAddressFromStr(String secret) {
    Seed seed = Seed.fromBase58(secret);
    return generateAddressFromSeed(seed);
  }


  static String getPublicHexFromSecret(String secret) {

      Seed seed = Seed.fromBase58(secret);
      IKeyPair keyPair = seed.keyPair();
      Uint8List pubBytes = keyPair.canonicalPubBytes();
      return Util.formatBytesAsHexString(pubBytes);
  }

  static Wallet generateAddressFromSeed(Seed seed) {
    IKeyPair keyPair = seed.keyPair();
    Uint8List pubBytes = keyPair.canonicalPubBytes();

    //keyPair.getPriv();

   // print(keyPair.getPriv().toRadixString(16));
    //print(keyPair.getPub().toRadixString(16));

    SHA256Digest sha = new SHA256Digest();
    sha.update(pubBytes, 0, pubBytes.length);

    var result = new Uint8List(sha.digestSize);
    sha.doFinal(result, 0);

    RIPEMD160Digest d = new RIPEMD160Digest();
    d.update(result, 0, result.length);
    var o = new Uint8List(d.digestSize);
    d.doFinal(o, 0);

    String publicKey = B58IdentiferCodecs.encode(
        pubBytes, B58IdentiferCodecs.VER_ACCOUNT_PUBLIC);
    String secretKey = B58IdentiferCodecs.encodeFamilySeed(seed.bytes());
    String address = B58IdentiferCodecs.encodeAddress(o);

    return new Wallet(secretKey, address, publicKey);
  }

  /// Return the signed Hex String
  static String signFromString(String data, String secret) {

      Seed seed = Seed.fromBase58(secret);
      IKeyPair keyPair = seed.keyPair();
      var signedData = keyPair.signMessage(Util.createUint8ListFromString(data));
      return Util.formatBytesAsHexString(signedData);
  }

  static Uint8List sign(Uint8List data, String secret) {
    Seed seed = Seed.fromBase58(secret);
    IKeyPair keyPair = seed.keyPair();
    return keyPair.signMessage(data);
  }


  static bool verify(Uint8List data,Uint8List sig,String publicKey){
    Uint8List pubBytes = Util.getPubBytesFromString(publicKey);

    K256KeyPair keyPair = new K256KeyPair(null,Util.createBigIntFromUint8List(pubBytes));
    return keyPair.verifySignature(data, sig);
  }


  static SignTx signTxFromJson(Map txJson){

    if (txJson == null || !txJson.containsKey('secret')) {
      throw Exception("missing key 'secret'");
    }

    return signTx(txJson, txJson['secret']);
  }

  static SignTx signTx(Map txMap, String secret) {
    if (txMap == null || !txMap.containsKey('tx_json')) {
      throw Exception("missing key 'tx_json'");
    }

    Map tx = txMap['tx_json'];
    if (!tx.containsKey('TransactionType')) {
      throw Exception("missing key 'TransactionType'");
    }

    TransactionType type = TransactionType.valueOf(tx['TransactionType']);
    Transaction transaction = new Transaction(type);

    transaction.parseFromJson(tx);

    SignedTransaction signed = transaction.sign(secret);
    return new SignTx(signed.tx_blob, signed.hash.toString());
  }

  static Uint8List aes256Encrypt(Uint8List plainBytes, Uint8List symKey) {
    final key = new Key(Util.paddingPass(symKey, 32));
    final iv = new IV(key.bytes.sublist(0, 16));

    final encrypter = Encrypter(AES(key, mode: AESMode.cbc));
    final encrypted = encrypter.encryptBytes(plainBytes, iv: iv);
    return encrypted.bytes;
  }

  static Uint8List aes256Descrypt(Uint8List cipherBytes, Uint8List symKey) {
    final key = new Key(Util.paddingPass(symKey, 32));
    final iv = new IV(key.bytes.sublist(0, 16));
    final encrypter = Encrypter(AES(key, mode: AESMode.cbc));
    Encrypted encrypted = new Encrypted(cipherBytes);
    final decrypted = encrypter.decryptBytes(encrypted, iv: iv);
    return Uint8List.fromList(decrypted);
  }

  static Uint8List eciesEncrypt(Uint8List plainBytes,String publicKey){
    Uint8List pubBytes = Util.getPubBytesFromString(publicKey);
    return Ecies.eciesEncrypt(plainBytes, pubBytes);
  }

  static Uint8List eciesDecrypt(Uint8List cipher,String secret){
    return Ecies.eciesDecrypt(cipher, Seed.fromBase58(secret));
  }

}
